@@ -40,6 +40,7 @@ CharaMangerWorker::CharaMangerWorker(CharaMangerModel *model, QObject *parent)
     , m_charaMangerInter(new CharaManger(CharaMangerService, "/com/deepin/daemon/Authenticate/CharaManger",
                                   QDBusConnection::systemBus(), this))
     , m_stopTimer(new QTimer(this))
+    , m_fileDescriptor(nullptr)
     , m_dbusSenderID("")
     , m_currentInputCharaType(0)
 {
@@ -252,15 +253,19 @@ void CharaMangerWorker::refreshDriverInfo()
 
 void CharaMangerWorker::entollStart(const QString &driverName, const int &charaType, const QString &charaName)
 {
+    m_model->setAddButtonStatus(false);
     qDebug() << " CharaMangerWorker::entollStart " << driverName << charaType << charaName;
     m_currentInputCharaType = charaType;
 
     m_fileDescriptor = new QDBusPendingReply<QDBusUnixFileDescriptor>();
+      // 设置超时时间为INT_MAX（约等于无限大），阻塞等待后端响应
+    m_charaMangerInter->setTimeout(INT_MAX);
     *m_fileDescriptor = m_charaMangerInter->EnrollStart(driverName, charaType, charaName);
 
     Q_EMIT requestMainWindowEnabled(false);
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(*m_fileDescriptor, this);
     connect(watcher, &QDBusPendingCallWatcher::finished, this, [=] {
+        m_model->setAddButtonStatus(true);
         if (m_fileDescriptor->isError()) {
             qDebug() << "get File Descriptor error! " << m_fileDescriptor->error();
         } else {
@@ -280,6 +285,8 @@ void CharaMangerWorker::entollStart(const QString &driverName, const int &charaT
         Q_EMIT requestMainWindowEnabled(true);
         watcher->deleteLater();
     });
+    // 设置超时时间为-1时，库函数实现为25s
+    m_charaMangerInter->setTimeout(-1);
 }
 
 void CharaMangerWorker::refreshUserEnrollStatus(const QString &senderid, const int &code, const QString &codeInfo)
