@@ -39,6 +39,7 @@ using namespace dcc::personalization;
 
 const QString Service = "com.deepin.daemon.Appearance";
 const QString Path    = "/com/deepin/daemon/Appearance";
+const QString effectMoveWindowArg = "kwin4_effect_translucency";
 
 static const std::vector<int> OPACITY_SLIDER {
     0,
@@ -83,6 +84,13 @@ PersonalizationWork::PersonalizationWork(PersonalizationModel *model, QObject *p
     connect(m_wm, &WM::CompositingAllowSwitchChanged, this, &PersonalizationWork::onCompositingAllowSwitch);
     connect(m_wm, &WM::compositingEnabledChanged, this, &PersonalizationWork::onWindowWM);
 
+    // 监听窗口圆角值变化信号，以及后续增加的其他属性值变化均可在此监听
+    QDBusConnection::sessionBus().connect(Service, Path,
+                                          "org.freedesktop.DBus.Properties",
+                                          "PropertiesChanged",
+                                          "sa{sv}as",
+                                          this,
+                                          SLOT(handlePropertiesChanged(QDBusMessage)));
 
     //获取最小化设置
     if (m_setting->keys().contains("effectLoad", Qt::CaseSensitivity::CaseInsensitive)) {
@@ -196,6 +204,18 @@ void PersonalizationWork::refreshWMState()
 {
     QDBusPendingCallWatcher *wmWatcher = new QDBusPendingCallWatcher(m_wmSwitcher->CurrentWM(), this);
     connect(wmWatcher, &QDBusPendingCallWatcher::finished, this, &PersonalizationWork::onGetCurrentWMFinished);
+
+    if (!m_effects) {
+        qWarning() << "The Interface of org::kde::kwin::Effects is nullptr.";
+        return;
+    }
+
+    bool isMoveWindow = m_effects->isEffectLoaded(effectMoveWindowArg);
+    qDebug() << Q_FUNC_INFO << isMoveWindow;
+    m_model->setIsMoveWindow(isMoveWindow);
+
+    //TODO: 关联打开移动窗口功能信号(kwin4_effect_translucency)，实时响应变化
+    //目前窗管无法提供该信号，待后续窗管提供信号后再处理
 }
 
 void PersonalizationWork::FontSizeChanged(const double value) const
@@ -528,6 +548,23 @@ void PersonalizationWork::windowSwitchWM(bool value)
 
 }
 
+void PersonalizationWork::movedWindowSwitchWM(bool value)
+{
+    if (!m_effects) {
+        qWarning() << "The Interface of org::kde::kwin::Effects is nullptr.";
+        return;
+    }
+
+    if (value) {
+        bool isload = m_effects->loadEffect(effectMoveWindowArg);
+        qDebug() << Q_FUNC_INFO << " The effect of  kwin4_effect_translucency is : " << isload;
+        m_model->setIsMoveWindow(isload);
+    } else {
+        m_effects->unloadEffect(effectMoveWindowArg);
+        m_model->setIsMoveWindow(false);
+    }
+}
+
 void PersonalizationWork::setOpacity(int opacity)
 {
     m_dbus->setOpacity(sliderValutToOpacity(opacity));
@@ -563,6 +600,27 @@ void PersonalizationWork::setWindowRadius(int radius)
     interface.setProperty("WindowRadius", radius);
 }
 
+void PersonalizationWork::handlePropertiesChanged(QDBusMessage msg)
+{
+    QList<QVariant> arguments = msg.arguments();
+    if (3 != arguments.count()) {
+        return;
+    }
+    QString interfaceName = msg.arguments().at(0).toString();
+    if (interfaceName == Service) {
+        QVariantMap changedProps = qdbus_cast<QVariantMap>(arguments.at(1).value<QDBusArgument>());
+        QStringList keys = changedProps.keys();
+        for (int i = 0; i < keys.size(); i++) {
+            // 监听窗口圆角值信号
+            if (keys.at(i) == "WindowRadius") {
+                int radius = static_cast<int>(changedProps.value(keys.at(i)).toInt());
+                m_model->setWindowRadius(radius);
+                return;
+            }
+        }
+    }
+}
+
 template<typename T>
 T PersonalizationWork::toSliderValue(std::vector<T> list, T value)
 {
