@@ -198,8 +198,14 @@ public:
 
     bool isIncreaseVolume() const;
     void setIncreaseVolume(bool value);
-    void initMicroPhone() { Q_EMIT microphoneOnChanged(m_microphoneOn); }
-    void initSpeaker() { Q_EMIT speakerOnChanged(m_speakerOn); }
+    void initMicroPhone() {
+        Q_EMIT microphoneOnChanged(m_microphoneOn);
+        Q_EMIT microphoneNameChanged(m_microphoneName);
+    }
+    void initSpeaker() {
+        Q_EMIT speakerOnChanged(m_speakerOn);
+        Q_EMIT speakerNameChanged(m_speakerName);
+    }
 
     inline QStringList bluetoothAudioModeOpts() { return m_bluetoothModeOpts; }
     void setBluetoothAudioModeOpts(const QStringList &modes);
@@ -212,6 +218,12 @@ public:
     inline int currentWaitSoundReceiptTime() { return m_waitSoundReceiptTime; }
     void setWaitSoundReceiptTime(const int receiptTime);
 
+    inline QString speakerName() const { return m_speakerName; }
+    void setSpeakerName(QString speakerVolume);
+
+    inline QString microphoneName() const { return m_microphoneName; }
+    void setMicrophoneName(QString microphoneName);
+
 Q_SIGNALS:
     void speakerOnChanged(bool speakerOn) const;
     void microphoneOnChanged(bool microphoneOn) const;
@@ -228,6 +240,8 @@ Q_SIGNALS:
     void isPortEnableChanged(bool enable) const;
     void bluetoothModeOptsChanged(const QStringList &modeOpts) const;
     void bluetoothModeChanged(const QString &mode);
+    void speakerNameChanged(const QString &name) const;
+    void microphoneNameChanged(const QString &name) const;
 
     void setPortChanged(const Port* port) const;
     //查询是否可用
@@ -261,6 +275,8 @@ private:
     double m_microphoneVolume;
     double m_maxUIVolume;
     int m_waitSoundReceiptTime;
+    QString m_speakerName;
+    QString m_microphoneName;
 
 #ifndef DCC_DISABLE_FEEDBACK
     double m_microphoneFeedback;
