@@ -25,7 +25,10 @@
 #include "clockitem.h"
 #include "systemtimezone.h"
 #include "formatsetting.h"
+#include "currencyformat.h"
+#include "numberformat.h"
 #include "window/gsettingwatcher.h"
+#include "window/dconfigwatcher.h"
 #include "window/mainwindow.h"
 
 #include <types/zoneinfo.h>
@@ -46,6 +49,8 @@ DatetimeModule::DatetimeModule(FrameProxyInterface *frameProxy, QObject *parent)
     , m_model(nullptr)
     , m_timezonelist(nullptr)
     , m_widget(nullptr)
+    , m_currencyFormatWidget(nullptr)
+    , m_numberFormatWidget(nullptr)
 {
     m_pMainWindow = dynamic_cast<MainWindow *>(m_frameProxy);
     GSettingWatcher::instance()->insertState("timezoneList");
@@ -240,6 +245,10 @@ void DatetimeModule::initSearchData()
         return ret;
     };
 
+    auto func_dsg_visible = [=](const QString &dsgSettings) {
+        return (DConfigWatcher::instance()->getStatus(DConfigWatcher::datetime, dsgSettings) != "Hidden");
+    };
+
     auto func_timezonelist_changed = [ = ]() {
         if (!m_frameProxy || !m_model) {
             return;
@@ -267,6 +276,25 @@ void DatetimeModule::initSearchData()
         m_frameProxy->setDetailVisible(module, formatSettings, tr("Short Time"), bTimeFormat);
         m_frameProxy->setDetailVisible(module, formatSettings, tr("Long Time"), bTimeFormat);
         m_frameProxy->setDetailVisible(module, formatSettings, tr("First Day of Week"), bTimeFormat);
+
+        //货币格式
+        bool bCurrencysymbol = func_dsg_visible("fromatsettingCurrencysymbol");
+        bool bPositive = func_dsg_visible("fromatsettingPositive");
+        bool bNegative = func_dsg_visible("fromatsettingNegative");
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Currency Format"), bTimeFormat && (bCurrencysymbol || bPositive || bNegative));
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Currency Symbol"), bTimeFormat && bCurrencysymbol);
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Positive Currency Format"), bTimeFormat && bPositive);
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Negative Currency Format"), bTimeFormat && bNegative);
+        //数字格式
+        bool bDecimalsymbol = func_dsg_visible("fromatsettingDecimalsymbol");
+        bool bDigitgroupingsymbol = func_dsg_visible("fromatsettingDigitgroupingsymbol");
+        bool bDigitgrouping = func_dsg_visible("fromatsettingDigitgrouping");
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Number Format"), bTimeFormat && (bDecimalsymbol || bDigitgroupingsymbol || bDigitgrouping));
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Decimal Symbol"), bTimeFormat && bDecimalsymbol);
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Digit Grouping Symbol"), bTimeFormat && bDigitgroupingsymbol);
+        m_frameProxy->setDetailVisible(module, formatSettings, tr("Digit Grouping"), bTimeFormat && bDigitgrouping);
+
+        m_frameProxy->updateSearchData(module);
     };
 
     auto func_setting_changed = [ = ]() {
@@ -290,6 +318,22 @@ void DatetimeModule::initSearchData()
         func_setting_changed();
      };
 
+    QStringList cbxList;
+    cbxList << "datetimefromatsettingCurrencysymbol"
+            << "datetimefromatsettingPositive"
+            << "datetimefromatsettingNegative"
+            << "datetimefromatsettingDecimalsymbol"
+            << "datetimefromatsettingDigitgroupingsymbol"
+            << "datetimefromatsettingDigitgrouping"
+            << "datetimefromatsettingExample";
+    connect(DConfigWatcher::instance(), &DConfigWatcher::requestUpdateSearchMenu, this, [=](const QString &moduleName, bool status) {
+        Q_UNUSED(status)
+        if (moduleName == "" || !cbxList.contains(moduleName)) {
+            return;
+        }
+        func_format_changed();
+    });
+
     //更新开/关时间同步显示“服务器”
     connect(m_model, &DatetimeModel::NTPChanged, [ = ](bool value) {
         m_frameProxy->setDetailVisible(module, timeSettings, tr("Server"), func_is_visible("timeSettings", true) && value);
@@ -382,6 +426,8 @@ void DatetimeModule::ensureZoneChooserDialog()
 
 void DatetimeModule::showFormatSetting()
 {
+    Q_ASSERT(m_model);
+
     m_fsetting = new DCC_NAMESPACE::datetime::FormatSetting(m_model);
     connect(m_fsetting, &FormatSetting::weekdayFormatChanged, this, &DatetimeModule::weekdayFormatChanged);
     connect(m_fsetting, &FormatSetting::shortDateFormatChanged, this, &DatetimeModule::shortDateFormatChanged);
@@ -395,8 +441,28 @@ void DatetimeModule::showFormatSetting()
     connect(m_model, &DatetimeModel::longTimeFormatChanged, m_fsetting, &FormatSetting::setCururentLongTimeFormat);
     connect(m_model, &DatetimeModel::shorTimeFormatChanged, m_fsetting, &FormatSetting::setCururentShortTimeFormat);
     connect(m_model, &DatetimeModel::weekStartDayFormatChanged, m_fsetting, &FormatSetting::setCururentWeekStartDayFormat);
-    m_frameProxy->pushWidget(this, m_fsetting);
     GSettingWatcher::instance()->bind("datetimeFromatsetting", m_fsetting);
+
+    m_currencyFormatWidget = new CurrencyFormat(m_model);
+    m_numberFormatWidget = new NumberFormat(m_model);
+
+    connect(m_currencyFormatWidget, &CurrencyFormat::currencySymbolFormatChanged, m_numberFormatWidget, &NumberFormat::SetCurrencySymbolFormat);
+    connect(m_currencyFormatWidget, &CurrencyFormat::positiveCurrencyFormatChanged, m_numberFormatWidget, &NumberFormat::SetPositiveCurrencyFormat);
+    connect(m_currencyFormatWidget, &CurrencyFormat::negativeCurrencyChanged, m_numberFormatWidget, &NumberFormat::SetNegativeCurrency);
+    m_numberFormatWidget->SetCurrencySymbolFormat(m_currencyFormatWidget->getFirstCurrencySymbolFormat());
+    m_numberFormatWidget->SetPositiveCurrencyFormat(m_currencyFormatWidget->getFirstPositiveCurrencyFormatPlace());
+    m_numberFormatWidget->SetNegativeCurrency(m_currencyFormatWidget->getFirstNegativeCurrencyPlace());
+
+    dcc::ContentWidget *formatSettingsWidget = new  dcc::ContentWidget;
+    QWidget *widget = new QWidget(formatSettingsWidget);
+    QVBoxLayout *layout = new QVBoxLayout(widget);
+    layout->addWidget(m_fsetting);
+    layout->addWidget(m_currencyFormatWidget);
+    layout->addWidget(m_numberFormatWidget);
+    layout->addStretch();
+    formatSettingsWidget->setContent(widget);
+
+    m_frameProxy->pushWidget(this, formatSettingsWidget);
 }
 
 void DatetimeModule::showTimezoneList()
@@ -505,6 +571,7 @@ void DatetimeModule::onPopWidget()
     QModelIndex index = list->model()->index(ETimezoneList, 0);
     list->setCurrentIndex(index);
     list->clicked(index);
+    m_widget->setFocus();
 }
 
 void DatetimeModule::closeDialog()
