@@ -137,6 +137,7 @@ void DisplayModule::preInitialize(bool sync, FrameProxyInterface::PushType pusht
     //获取的主屏的信息是错误的，所以不能直接使用。现在的方法是通过/com/deepin/daemon/Display服务获取主屏的名称
     //然后再在QGuiApplication::screens()中匹配，从而获取主屏的信息。
     connect(m_displayModel, &DisplayModel::monitorListChanged, this, [=] {
+        qInfo() << "Moniter list changed";
         if (m_pMainWindow) {
             for (auto mon : m_displayModel->monitorList()) {
                 if (mon->isPrimary()) {
@@ -146,7 +147,21 @@ void DisplayModule::preInitialize(bool sync, FrameProxyInterface::PushType pusht
         }
     });
 
+    // 在wayland环境下，仅单屏切换的时候，会出现display服务告知主屏已变化，但是Qt的屏幕信息还没有准备好的情况
+    // 此处监听一下屏幕增加的信号，然后重新获取数据设置一下主屏（如果之前主屏已经设置了，此时设置并不会有影响）
+    connect(qApp, &QApplication::screenAdded, this, [this] {
+        qInfo() << "Screen added";
+        if (m_pMainWindow && QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)) {
+            for (auto mon : m_displayModel->monitorList()) {
+                if (mon->isPrimary()) {
+                    m_pMainWindow->setPrimaryScreen(mon->getQScreen());
+                }
+            }
+        }
+    });
+
     connect(m_displayModel, &DisplayModel::primaryScreenChanged, this, [=] (QString primary) {
+        qInfo() << "On display model primary screen changed: " << primary;
         if (m_pMainWindow && !primary.isEmpty()) {
             for (auto mon : m_displayModel->monitorList()) {
                 if (mon->name() == primary) {
@@ -209,7 +224,13 @@ void DisplayModule::showSingleScreenWidget()
     BrightnessWidget *brightnessWidget = new BrightnessWidget(singleScreenWidget);
     brightnessWidget->setMode(m_displayModel);
     contentLayout->addWidget(brightnessWidget);
-    const bool brightnessIsEnabled = m_displayModel->brightnessEnable() && m_displayModel->primaryMonitor() && m_displayModel->primaryMonitor()->canBrightness();
+    bool canBrightness = std::any_of(m_displayModel->monitorList().begin(), m_displayModel->monitorList().end(), [](Monitor* moi){
+        if(moi->enable()){
+            return moi->canBrightness();
+        }
+        return false;
+    });
+    const bool brightnessIsEnabled = m_displayModel->brightnessEnable() && canBrightness;
     brightnessWidget->setVisible(brightnessIsEnabled);
     connect(brightnessWidget, &BrightnessWidget::requestSetColorTemperature, m_displayWorker, &DisplayWorker::setColorTemperature);
     connect(brightnessWidget, &BrightnessWidget::requestSetMonitorBrightness, m_displayWorker, &DisplayWorker::setMonitorBrightness);
@@ -260,7 +281,14 @@ void DisplayModule::showSingleScreenWidget()
     m_displayWidget->setContent(singleScreenWidget);
 
     connect(m_displayModel, &DisplayModel::brightnessEnableChanged, this, [brightnessWidget, scalingSpacerItem, this](const bool enable) {
-        const bool visible = enable && m_displayModel->primaryMonitor() && m_displayModel->primaryMonitor()->canBrightness();
+        bool canBrightness = std::any_of(m_displayModel->monitorList().begin(), m_displayModel->monitorList().end(), [](Monitor* moi){
+            if(moi->enable()){
+                return moi->canBrightness();
+            }
+            return false;
+        });
+
+        const bool visible = enable && canBrightness;
         scalingSpacerItem->changeSize(0, visible ? 20 : 0);
         brightnessWidget->setVisible(visible);
     });
@@ -273,7 +301,12 @@ void DisplayModule::showMultiScreenWidget()
         windowUpdate();
     });
 
-    MultiScreenWidget *multiScreenWidget = new MultiScreenWidget(m_pMainWindow);
+    MultiScreenWidget *multiScreenWidget = new MultiScreenWidget();
+    //wayland情况下这里设置父窗口会影响窗口最大化/还原的问题，详见bug 125867
+    if(!QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)){
+        multiScreenWidget->setParent(m_pMainWindow);
+    }
+
     multiScreenWidget->setModel(m_displayModel);
     connect(multiScreenWidget, &MultiScreenWidget::requestSwitchMode, m_displayWorker, &DisplayWorker::switchMode);
     connect(multiScreenWidget, &MultiScreenWidget::requestSetMonitorPosition, m_displayWorker, &DisplayWorker::setMonitorPosition);
@@ -297,6 +330,9 @@ void DisplayModule::showMultiScreenWidget()
                 m_displayWorker->setCurrentFillMode(m, currfillMode);
         }
     });
+    if(QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)){
+        connect(m_pMainWindow, &MainWindow::mainwindowStateChange, multiScreenWidget, &MultiScreenWidget::onMainwindowStateChanged);
+    }
 
     connect(multiScreenWidget, &MultiScreenWidget::requestSetRotate, this, &DisplayModule::onRequestSetRotate, Qt::QueuedConnection);
     connect(multiScreenWidget, &MultiScreenWidget::requestSetMainwindowRect, this, [=](Monitor *moi,  bool isInit) {
