@@ -55,9 +55,9 @@ MultiScreenWidget::MultiScreenWidget(QWidget *parent)
     , m_monitorControlWidget(new MonitorControlWidget(240, this)) //根据产品设计更改出事高度为240
     , m_fullIndication(new MonitorIndicator(this))
     , m_modeSettingsItem(new SettingsItem(this))
-    , m_modeCombox(new QComboBox(this))
+    , m_modeCombox(new QComboBox(m_modeSettingsItem))
     , m_primarySettingsItem(new SettingsItem(this))
-    , m_primaryCombox(new QComboBox(this))
+    , m_primaryCombox(new QComboBox(m_primarySettingsItem))
     , m_brightnessSpacerItem(new QSpacerItem(0, 20))
     , m_brightnessWidget(new BrightnessWidget(this))
     , m_scalingWidget(new ScalingWidget(this))
@@ -181,6 +181,7 @@ void MultiScreenWidget::setModel(dcc::display::DisplayModel *model)
             m_modeCombox->setCurrentIndex(0);
             m_primarySettingsItem->setVisible(false);
             m_brightnessWidget->showBrightness();
+            m_brightnessWidget->setVisible(m_model->brightnessEnable());
             m_monitorControlWidget->setModel(m_model);
             for (auto dlg : m_secondaryScreenDlgList) {
                 dlg->deleteLater();
@@ -197,7 +198,7 @@ void MultiScreenWidget::setModel(dcc::display::DisplayModel *model)
             for (int idx = 0; idx < monitorList.size(); ++idx) {
                 auto monitor = monitorList[idx];
                 if (monitor->enable()) {
-                    m_modeCombox->setCurrentIndex(idx + 2);
+                    setModeCurrentIndex(monitor->name());
                     m_monitorControlWidget->setModel(m_model, monitor);
                     break;
                 }
@@ -233,7 +234,7 @@ void MultiScreenWidget::setModel(dcc::display::DisplayModel *model)
             for (int idx = 0; idx < monitorList.size(); ++idx) {
                 auto monitor = monitorList[idx];
                 if (monitor->enable()) {
-                    m_modeCombox->setCurrentIndex(idx + 2);
+                    setModeCurrentIndex(monitor->name());
                     break;
                 }
             }
@@ -343,21 +344,32 @@ void MultiScreenWidget::onGSettingsChanged(const QString &gsettingsName, const Q
 
 void MultiScreenWidget::initModeList()
 {
-    m_modeCombox->addItem(tr("Duplicate"));
-    m_modeCombox->addItem(tr("Extend"));
+    m_modeCombox->addItem(tr("Duplicate"), "Duplicate");
+    m_modeCombox->addItem(tr("Extend"), "Extend");
 
     auto monitorList = m_model->monitorList();
     for (int idx = 0; idx < monitorList.size(); ++idx) {
         auto monitor = monitorList[idx];
+        connect(monitor, &Monitor::enableChanged, this, [ this ](bool enable){
+            if(m_model->displayMode() == SINGLE_MODE){
+                for (auto moni : m_model->monitorList()) {
+                    if(moni->enable()){
+                        setModeCurrentIndex(moni->name());
+                    }
+                    break;
+                }
+            }
+        });
+
         if(monitorList.size() <= 2)
-            m_modeCombox->addItem(tr("Only on %1").arg(monitor->name()));
+            m_modeCombox->addItem(tr("Only on %1").arg(monitor->name()), monitor->name());
 
         if (m_model->displayMode() == MERGE_MODE) {
             m_modeCombox->setCurrentIndex(0);
         } else if (m_model->displayMode() == EXTEND_MODE) {
             m_modeCombox->setCurrentIndex(1);
         } else if (m_model->displayMode() == SINGLE_MODE && monitor->enable()) {
-            m_modeCombox->setCurrentIndex(idx + 2);
+            setModeCurrentIndex(monitor->name());
         }
     }
 }
@@ -381,13 +393,19 @@ void MultiScreenWidget::initSecondaryScreenDialog()
         }
         m_secondaryScreenDlgList.clear();
 
+        // x11 上 dialog 没有父窗口会导致主程序退出缓慢
+        // wayland上子窗口为适应多屏就不该设置父窗口，由窗管设置
+        QWidget *parent = this;
+        if (!qgetenv("WAYLAND_DISPLAY").isEmpty()) {
+            parent = nullptr;
+        }
         for (const auto &monitor : m_model->monitorList()) {
             if (monitor == m_model->primaryMonitor()) {
                 QTimer::singleShot(0, this, [=] { requestSetMainwindowRect(m_model->primaryMonitor(), true); });
                 continue;
             }
 
-            SecondaryScreenDialog *dlg = new SecondaryScreenDialog(this);
+            SecondaryScreenDialog *dlg = new SecondaryScreenDialog(parent);
             dlg->setAttribute(Qt::WA_WState_WindowOpacitySet);
             dlg->setModel(m_model, monitor);
             connect(dlg, &SecondaryScreenDialog::requestRecognize, this, &MultiScreenWidget::requestRecognize);
@@ -401,13 +419,19 @@ void MultiScreenWidget::initSecondaryScreenDialog()
             connect(dlg, &SecondaryScreenDialog::requestCloseRecognize, this, &MultiScreenWidget::onRequestCloseRecognize);
             connect(this, &MultiScreenWidget::requestGatherEnabled, dlg, &SecondaryScreenDialog::requestGatherEnabled);
             m_secondaryScreenDlgList.append(dlg);
-            
-            dlg->show();
+
+            // 要先移动后显示
+            dlg->resetDialog();
         }
         activateWindow();
 
         if (!qgetenv("WAYLAND_DISPLAY").isEmpty()) {
             m_resetSecondaryScreenDlgTimer->start();
+            QTimer::singleShot(10, this, [=] {
+                for (auto dlg : m_secondaryScreenDlgList) {
+                    dlg->show();
+                }
+            });
         } else {
             onResetSecondaryScreenDlgTimerOut();
         }
@@ -419,33 +443,38 @@ void MultiScreenWidget::onGatherWindows(const QPoint cursor)
     Q_EMIT requestGatherEnabled(false);
 
     for (const auto &monitor : m_model->monitorList()) {
-        auto mrt = monitor->rect();
+        auto screen = monitor->getQScreen();
+        auto mrt = screen->geometry();
+
         if (mrt.contains(cursor.x(), cursor.y())) {
             for (QWidget *w : qApp->topLevelWidgets()) {
                 if (DMainWindow *mainWin = qobject_cast<DMainWindow *>(w)) {
                     auto rt = mainWin->rect();
-                    if (rt.width() > monitor->w())
-                        rt.setWidth(monitor->w());
+                    if (rt.width() > screen->geometry().width())
+                        rt.setWidth(screen->geometry().width());
 
-                    if (rt.height() > monitor->h())
-                        rt.setHeight(monitor->h());
+                    if (rt.height() > screen->geometry().height())
+                        rt.setHeight(screen->geometry().height());
 
-                    auto tsize = (mrt.size() / m_model->monitorScale(monitor) - rt.size()) / 2;
-                    rt.moveTo(monitor->x() + tsize.width(), monitor->y() + tsize.height());
+                    auto tsize = (mrt.size() - rt.size()) / 2;
+                    rt.moveTo(screen->geometry().topLeft().x() + tsize.width(), screen->geometry().topLeft().y() + tsize.height());
                     mainWin->setGeometry(rt);
                 }
             }
 
             for (auto dlg : m_secondaryScreenDlgList) {
                 auto rt = dlg->rect();
-                if (rt.width() > monitor->w())
-                    rt.setWidth(monitor->w());
+                if (rt.width() > screen->geometry().width())
+                    rt.setWidth(screen->geometry().width());
 
-                if (rt.height() > monitor->h())
-                    rt.setHeight(monitor->h());
-                auto tsize = (mrt.size() / m_model->monitorScale(monitor) - rt.size()) / 2;
-                rt.moveTo(monitor->x() + tsize.width(), monitor->y() + tsize.height());
-                dlg->setGeometry(rt);
+                if (rt.height() > screen->geometry().height())
+                    rt.setHeight(screen->geometry().height());
+
+                auto tsize = (mrt.size() - rt.size()) / 2;
+                rt.moveTo(screen->geometry().topLeft().x() + tsize.width(), screen->geometry().topLeft().y() + tsize.height());
+                dlg->QDialog::setGeometry(rt);
+                // 将副窗口置顶
+                dlg->activateWindow();
             }
             break;
         }
@@ -552,3 +581,28 @@ void MultiScreenWidget::keyPressEvent(QKeyEvent *e)
 
     QWidget::keyPressEvent(e);
 }
+
+void MultiScreenWidget::setModeCurrentIndex(const QString &monitorName)
+{
+    if(monitorName.isEmpty())
+        return;
+
+    qDebug() << Q_FUNC_INFO << monitorName;
+    int index = m_modeCombox->findData(monitorName);
+    if (index != -1) {
+        m_modeCombox->blockSignals(true);
+        m_modeCombox->setCurrentIndex(index);
+        m_modeCombox->blockSignals(false);
+    }
+}
+
+void MultiScreenWidget::onMainwindowStateChanged(int type)
+{
+    qDebug() << Q_FUNC_INFO << type;
+    if(QEvent::Show == type || QEvent::Hide == type ){
+        for (auto item : m_secondaryScreenDlgList) {
+            if(item != nullptr)
+                item->setVisible(QEvent::Show == type);
+        }
+    }
+}
