@@ -90,6 +90,10 @@ private:
     void initModeList();
     void initPrimaryList();
     void initSecondaryScreenDialog();
+    void setModeCurrentIndex(const QString &monitorName);
+
+public Q_SLOTS:
+    void onMainwindowStateChanged(int type);
 
 private Q_SLOTS:
     void onGatherWindows(const QPoint cursor);
