@@ -21,7 +21,6 @@
 
 #pragma once
 #include "interface/namespace.h"
-#include "waylandgrab.h"
 
 #include <dfilechooseredit.h>
 
@@ -31,6 +30,8 @@ QT_BEGIN_NAMESPACE
 class QLabel;
 QT_END_NAMESPACE
 
+class WaylandGrab;
+
 namespace dcc {
 namespace keyboard {
 class ShortcutModel;
@@ -72,6 +73,7 @@ public Q_SLOTS:
 protected:
     void keyPressEvent(QKeyEvent *ke) override;
     void keyReleaseEvent(QKeyEvent *ke) override;
+    void mousePressEvent(QMouseEvent *e) override;
 
 private:
     dcc::keyboard::KeyboardWorker *m_work;
@@ -83,7 +85,7 @@ private:
     dcc::keyboard::ShortcutModel *m_model;
     dcc::widgets::ButtonTuple *m_buttonTuple;
 
-    WaylandGrab *waylandGrab = nullptr;
+    WaylandGrab *m_waylandGrab;
 };
 }
 }
