@@ -87,6 +87,7 @@ private:
     void refreshIcon();
     void showWaitSoundPortStatus(bool showStatus);
     void refreshActivePortShow(const dcc::sound::Port *port);
+    bool hasVirtualSource();
 
 private:
     dcc::sound::SoundModel *m_model{nullptr};
@@ -112,6 +113,8 @@ private:
     bool m_fristChangePort;
     bool m_currentBluetoothPortStatus;
     QTimer *m_waitStatusChangeTimer;
+    // 名字
+    QString m_microphoneName;
 };
 
 }
