@@ -86,6 +86,12 @@ NativeInfoWidget::NativeInfoWidget(SystemInfoModel *model, QWidget *parent)
     , m_mainLayout(new QVBoxLayout(this))
     , m_hostNameLayout(new QHBoxLayout(this))
     , m_hostNameSettingItem(new SettingsItem(this))
+    , m_hostNameTitleLabel(nullptr)
+    , m_hostNameLabel(nullptr)
+    , m_hostNameBtn(nullptr)
+    , m_hostNameLineEdit(nullptr)
+    , m_productName(nullptr)
+    , m_versionNumber(nullptr)
     , isContensServers(false)
     , m_hostname(model ? model->hostName() : "")
     , m_hostnameEdit(m_hostname)
