@@ -2,130 +2,109 @@
 <context>
     <name>PasswordWidget</name>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="57"/>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="146"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="62"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="145"/>
         <source>Passwords do not match</source>
         <translation>Parolalar eşleşmiyor</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="65"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="71"/>
         <source>The hint is visible to all users. Do not include the password here.</source>
         <translation>İpucu tüm kullanıcılar tarafından görülebilir. Parolayı buraya dahil etmeyin.</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="86"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="89"/>
         <source>New Password</source>
         <translation>Yeni Parola</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="120"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="111"/>
         <source>Repeat Password</source>
         <translation>Parolayı Tekrarla</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="128"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="119"/>
         <source>Password Hint</source>
         <translation>Parola İpucu</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="137"/>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="138"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="128"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="129"/>
         <source>Required</source>
         <translation>Gereklidir</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="139"/>
+        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="130"/>
         <source>Optional</source>
         <translation>Seçimlik</translation>
     </message>
-    <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="221"/>
-        <source>Strong</source>
-        <translation>Güçlü</translation>
-    </message>
-    <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="231"/>
-        <source>Medium</source>
-        <translation>Orta</translation>
-    </message>
-    <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="240"/>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="253"/>
-        <source>A stronger password is recommended: more than 8 characters, and contains 3 of the four character types: lowercase letters, uppercase letters, numbers, and symbols.</source>
-        <translation>Güçlü bir parola tavsiye ederiz: 8 karakterden daha fazladır ve dört karakter türünden 3&apos;ünü içerir: küçük harfler, büyük harfler, sayılar ve simgeler.</translation>
-    </message>
-    <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="244"/>
-        <source>Weak</source>
-        <translation>Zayıf</translation>
-    </message>
-    <message>
-        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="255"/>
-        <source>Error occurred when reading the configuration files of password rules!</source>
-        <translation>Parola kurallarının yapılandırma dosyaları okunduğu zaman hata oluştu!</translation>
-    </message>
 </context>
 <context>
     <name>PwqualityManager</name>
     <message>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="76"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="78"/>
         <source>Password cannot be empty</source>
         <translation>Parola boş olamaz</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="77"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="79"/>
         <source>Password must have at least %1 characters</source>
         <translation>Parola en az %1 karakter olmalıdır</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="78"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="80"/>
         <source>Password must be no more than %1 characters</source>
         <translation>Parola %1 karakterden fazla olmamalıdır</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="79"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="81"/>
         <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
         <translation>Parola yalnızca İngilizce harfler (büyük/küçük harfe duyarlı), sayılar veya özel simgeler içerebilir (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="80"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="82"/>
         <source>No more than %1 palindrome characters please</source>
         <translation>En fazla %1 palindrom karakter lütfen</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="81"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="83"/>
         <source>No more than %1 monotonic characters please</source>
         <translation>%1&apos;den fazla monoton karakter yok lütfen</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="82"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="84"/>
         <source>No more than %1 repeating characters please</source>
         <translation>Lütfen %1&apos;den fazla yinelenen karakter yok</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="87"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="85"/>
+        <source>The password should differ from the username</source>
+        <translation>Şifre isminden adından farklı olmalıdır</translation>
+    </message>
+    <message>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="91"/>
         <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
         <translation>Parola büyük harfler, küçük harfler, sayılar ve semboller içermeli (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="88"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="92"/>
         <source>Password must not contain more than 4 palindrome characters</source>
         <translation>Parola 4&apos;ten fazla tersten okunduğunda aynı olan karakter içermemelidir</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="89"/>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="92"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="93"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="96"/>
         <source>Do not use common words and combinations as password</source>
         <translation>Parola olarak bilinen kelime ve kombinasyonlarını kullanmayın</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="90"/>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="91"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="94"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="95"/>
         <source>Create a strong password please</source>
         <translation>Lütfen güçlü bir parola oluşturun</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/pwqualitymanager.cpp" line="97"/>
+        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="102"/>
         <source>It does not meet password rules</source>
         <translation>Parola kurallarına uymuyor</translation>
     </message>
@@ -133,7 +112,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/reset-password-dialog/utils.h" line="71"/>
+        <location filename="../src/reset-password-dialog/utils.h" line="72"/>
         <source>It cannot be empty</source>
         <translation>Boş olamaz</translation>
     </message>
@@ -141,110 +120,128 @@
 <context>
     <name>ResetPasswordDialog</name>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="109"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="119"/>
         <source>Resetting the password will clear the data stored in the keyring</source>
         <translation>Parolanın sıfırlanması, anahtarlıkta depolanan verileri siler</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="111"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="167"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="206"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="121"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="177"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="224"/>
         <source>Cancel</source>
         <translation>İptal</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="120"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="130"/>
         <source>Security Questions</source>
         <translation>Güvenlik Soruları</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="155"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="165"/>
         <source>Reset Password</source>
         <translation>Parolayı Sıfırla</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="156"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="191"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="194"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="166"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="209"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="212"/>
         <source>Next</source>
         <translation>Sonraki</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="159"/>
-        <source>Reset Password By Union ID</source>
-        <translation>Parolayı Union ID ile sıfırla</translation>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="169"/>
+        <source>Reset Password By UOS ID</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="160"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="191"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="194"/>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="202"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="170"/>
         <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="209"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="212"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="220"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="227"/>
         <source>Reset</source>
         <translation>Sıfırla</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="166"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="176"/>
         <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
         <translation>Parolayı sıfırlamak, anahtarlığınızda saklanan verileri siler ve tekrar giriş yapmalısınız, lütfen dosyaları önceden kaydedin</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="167"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="177"/>
         <source>Confirm and Reset</source>
         <translation>Onayla ve Sıfırla</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="260"/>
+        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="302"/>
         <source>Successfully reset, please log in and unlock with the new password</source>
         <translation>Başarıyla sıfırladın, lütfen  yeni parola ile giriş yapın ve kilidi açın</translation>
     </message>
 </context>
+<context>
+    <name>SecurityLevelItem</name>
+    <message>
+        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="73"/>
+        <source>Weak</source>
+        <translation>Zayıf</translation>
+    </message>
+    <message>
+        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="83"/>
+        <source>Medium</source>
+        <translation>Orta</translation>
+    </message>
+    <message>
+        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="93"/>
+        <source>Strong</source>
+        <translation>Güçlü</translation>
+    </message>
+</context>
 <context>
     <name>SecurityQuestionsWidget</name>
     <message>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="126"/>
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="127"/>
         <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="128"/>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="129"/>
         <source>Required</source>
         <translation>Gereklidir</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="131"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="130"/>
         <source>What&apos;s the name of the city where you were born?</source>
         <translation>Doğduğun şehrin adı nedir?</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="132"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="131"/>
         <source>What&apos;s the name of the first school you attended?</source>
         <translation>İlk okuduğun okulun adı nedir?</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="133"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="132"/>
         <source>Who do you love the most in this world?</source>
         <translation>Dünyada en çok kimi seviyorsun?</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="134"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="133"/>
         <source>What&apos;s your favorite animal?</source>
         <translation>Gözde hayvanın nedir?</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="135"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="134"/>
         <source>What&apos;s your favorite song?</source>
         <translation>Gözde şarkın nedir?</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="136"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="135"/>
         <source>What&apos;s your nickname?</source>
         <translation>Takma adın nedir?</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="186"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="185"/>
         <source>Wrong answer</source>
         <translation>Yanlış cevap</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="201"/>
+        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="200"/>
         <source>Keep the answer under 30 characters</source>
         <translation>Cevap 30 karakterden az olmalıdır</translation>
     </message>
@@ -252,87 +249,82 @@
 <context>
     <name>UnionIDWidget</name>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="63"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="62"/>
         <source>Phone/Email</source>
         <translation>Telefon/E-posta</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="69"/>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="136"/>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="289"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="68"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="135"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="284"/>
         <source>Get Code</source>
         <translation>Kodu Al</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="89"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="88"/>
         <source>Connecting to the Internet...</source>
         <translation>İnternet&apos;e bağlanıyor...</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="101"/>
-        <source>The user account is not linked to Union ID</source>
-        <translation>Kullanıcı hesabı Union ID&apos;ye bağlı değil</translation>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="100"/>
+        <source>The user account is not linked to UOS ID</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="114"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="113"/>
         <source>Network disconnected, please retry after connected</source>
         <translation>Ağ bağlantısı kesildi, lütfen bağlandıktan sonra tekrar dene</translation>
     </message>
     <message>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="133"/>
         <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="134"/>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="135"/>
         <source>Required</source>
         <translation>Gereklidir</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="170"/>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="185"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="175"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="192"/>
         <source>Phone/Email format is incorrect</source>
         <translation>Telefon/E-posta biçimi yanlış</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="239"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="246"/>
         <source>System error</source>
         <translation>Sistem hatası</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="241"/>
-        <source>Login expired, please sign in to the Union ID again</source>
-        <translation>Girişin süresi doldu, lütfen Union ID&apos;de tekrar oturum açın</translation>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="248"/>
+        <source>Login expired, please sign in to the UOS ID again</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="243"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="250"/>
         <source>Network error</source>
         <translation>Ağ hatası</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="245"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="252"/>
         <source>You have reached the number limit to get the code today</source>
         <translation>Bugün kodu almak için sayı sınırına ulaştınız</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="246"/>
-        <source>The Union ID is not linked to a user account</source>
-        <translation>Union ID bir kullanıcı hesabına bağlı değil</translation>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="253"/>
+        <source>The UOS ID is not linked to a user account</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="255"/>
-        <source>It cannot be empty</source>
-        <translation>Boş olamaz</translation>
-    </message>
-    <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="292"/>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="334"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="287"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="329"/>
         <source>Resend (%1s)</source>
         <translation>Yeniden gönderiliyor  (%1s)</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="353"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="349"/>
         <source>Failed to get the code</source>
         <translation>Kod alımı başarısız oldu.</translation>
     </message>
     <message>
-        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="376"/>
+        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="374"/>
         <source>Wrong verification code</source>
         <translation>Yanlış doğrulama kodu</translation>
     </message>
